%%
%% This is file `npr.cls',
%%
%% Copyright (c) 2008--2020 Nuclear Physics Review
%% http://www.npr.ac.cn
%% mailto npr@impcas.ac.cn

%------------------------------------------------------------------------------------------------------

\NeedsTeXFormat{LaTeX2e}[2017/04/15]
\ProvidesClass{npr}[2020/04/09 v2.0 Nuclear Physics Review template]

% 报错和警告
\newcommand\class@error[1]{%
  \ClassError{npr}{#1}{}%
}
\newcommand\class@warning[1]{%
  \ClassWaring{npr}{#1}%
}

% 检查 \LaTeXe{} kernel 版本
\@ifl@t@r\fmtversion{2017/04/15}{}{
  \class@error{%
    TeX Live 2017 or later version is required to compile this document%
  }
}

% 检查编译引擎，要求使用 XeLaTeX。
\RequirePackage{iftex}
\ifXeTeX\else
  \class@error{XeLaTeX is required to compile this document}
\fi

% 提供 key-value 接口。
\RequirePackage{kvdefinekeys}
\RequirePackage{kvsetkeys}
\RequirePackage{kvoptions}

\kv@set@family@handler{class@key}{%
  \@namedef{class@#1@@name}{#1}%
  \def\class@@default{}%
  \def\class@@choices{}%
  \kv@define@key{class@value}{name}{%
    \@namedef{class@#1@@name}{##1}%
  }%
  \@namedef{class@#1@@check}{}%
  \@namedef{class@#1@@code}{}%
  \kv@define@key{class@value}{choices}{%
    \def\class@@choices{##1}%
    \@namedef{class@#1@@reset}{}%
    \@namedef{class@#1@@check}{%
      \@ifundefined{%
        ifclass@\@nameuse{class@#1@@name}@\@nameuse{class@\@nameuse{class@#1@@name}}%
      }{%
        \class@error{Invalid value "#1 = \@nameuse{class@\@nameuse{class@#1@@name}}"}%
      }%
      \@nameuse{class@#1@@reset}%
      \@nameuse{class@\@nameuse{class@#1@@name}@\@nameuse{class@\@nameuse{class@#1@@name}}true}%
    }%
  }%
  \kv@define@key{class@value}{default}{%
    \def\class@@default{##1}%
  }%
  \kvsetkeys{class@value}{#2}%
  \@namedef{class@\@nameuse{class@#1@@name}}{}%
  \kv@set@family@handler{class@choice}{%
    \ifx\class@@default\@empty
      \def\class@@default{##1}%
    \fi
    \expandafter\newif\csname ifclass@\@nameuse{class@#1@@name}@##1\endcsname
    \expandafter\g@addto@macro\csname class@#1@@reset\endcsname{%
      \@nameuse{class@\@nameuse{class@#1@@name}@##1false}%
    }%
  }%
  \kvsetkeys@expandafter{class@choice}{\class@@choices}%
  \expandafter\let\csname class@\@nameuse{class@#1@@name}\endcsname\class@@default
  \expandafter\ifx\csname class@\@nameuse{class@#1@@name}\endcsname\@empty\else
    \@nameuse{class@#1@@check}%
  \fi
  \kv@define@key{class}{#1}{%
    \@namedef{class@\@nameuse{class@#1@@name}}{##1}%
    \@nameuse{class@#1@@check}%
    \@nameuse{class@#1@@code}%
  }%
}

\newcommand\class@define@key[1]{%
  \kvsetkeys{class@key}{#1}%
}
\newcommand\classsetup[1]{%
  \kvsetkeys{class}{#1}%
}
\newcommand\class@option@hook[2]{%
  \expandafter\g@addto@macro\csname class@#1@@code\endcsname{#2}%
}

\class@define@key{
  language = {
    choices = {
      chinese,
      english,
    },
    default = chinese,
  },
  fontset = {
    choices = {
      windows,
      mac,
      ubuntu,
      fandol,
      none,
    },
    default = none,
  },
}

% 使用 \pkg{kvoptions} 提供的 key-value 接口，
\SetupKeyvalOptions{
  family  = class,
  prefix  = class@,
  setkeys = \kvsetkeys,
}

\PassOptionsToClass{UTF8,a4paper,scheme=plain,fontset=none,zihao=5,twoside,twocolumn}{ctexart}
\PassOptionsToPackage{quiet}{xeCJK}

\DeclareDefaultOption{\PassOptionsToClass{\CurrentOption}{ctexart}}
\ProcessKeyvalOptions*

% 载入 \cls{ctexart} 文档类，要求为 2.4.9 或更高的版本。
\LoadClass{ctexart}[2017/04/01]

\RequirePackage{fancyhdr}
\RequirePackage{lastpage}
\RequirePackage{refcount}
\RequirePackage{fontspec}[2017/03/31]
\RequirePackage[tbtags]{amsmath}
\RequirePackage{unicode-math}
\RequirePackage{fancyhdr}
\RequirePackage{caption}
\RequirePackage[sort&compress]{natbib}
\RequirePackage{url}
\RequirePackage{etoolbox}

% 对冲突的宏包报错。
\RequirePackage{filehook}
\newcommand\class@package@conflict[2]{
  \AtBeginOfPackageFile*{#2}{
    \class@error{The "#2" package is incompatible with required "#1"}
  }
}
\class@package@conflict{unicode-math}{amscd}
\class@package@conflict{unicode-math}{amsfonts}
\class@package@conflict{unicode-math}{amssymb}
\class@package@conflict{unicode-math}{bbm}
\class@package@conflict{unicode-math}{bm}
\class@package@conflict{unicode-math}{eucal}
\class@package@conflict{unicode-math}{eufrak}
\class@package@conflict{unicode-math}{mathrsfs}

%------------------------------ geometry --------------------------------------

% \setlength{\textheight}{237.5mm}
% \setlength{\textwidth}{176mm}
% \setlength{\topmargin}{-0.338in}
% \leftmargin 6mm
% \evensidemargin 0mm
% \headheight 14mm   %12mm
% \headsep 4mm  %5mm
% \footskip 0pt
% \oddsidemargin-8.0mm
% \evensidemargin-8.1mm
% \columnsep 7mm

\RequirePackage{geometry}
\geometry{
  top = 35mm,
  bottom = 24.5mm,
  hmargin = 17mm,
  headheight = 14mm,
  headsep = 4mm,
  footskip = 10mm,
  columnsep = 7mm,
}

%-------------------------------语言----------------------------------------------------------

\let\class@main@language\class@language
\class@option@hook{language}{%
  \ifx\@begindocumenthook\@undefined
    \let\class@main@language\class@language
  \fi
}
\newcommand\class@reset@main@language{
  \classsetup{language = \class@main@language}
}

% 由于 Unicode 的一些标点符号是中西文混用的：
% 所以要根据语言设置正确的字体。
\newcommand\class@set@punctuations{%
  \ifclass@language@chinese
    \xeCJKDeclareCharClass{FullLeft}{"2018, "201C}%
    \xeCJKDeclareCharClass{FullRight}{
      "00B7, "2019, "201D, "2013, "2014, "2025, "2026, "2E3A,
    }%
    \xeCJKsetup{CJKmath = true}
  \else
    \ifclass@language@english
      \xeCJKDeclareCharClass{HalfLeft}{"2018, "201C}%
      \xeCJKDeclareCharClass{HalfRight}{
        "00B7, "2019, "201D, "2013, "2014, "2025, "2026, "2E3A,
      }%
      \xeCJKsetup{CJKmath = false}
    \fi
  \fi
}
\class@set@punctuations
\class@option@hook{language}{\class@set@punctuations}

%-------------------------------字体和字号----------------------------------------------------------

\class@define@key{
  font = {
    choices = {
      times,
      termes,
      xits,
      libertinus,
      lm,
      auto,
      none,
    },
    default = auto,
  },
  cjk-font = {
    name = cjk@font,
    choices = {
      windows,
      mac,
      noto,
      fandol,
      auto,
      none,
    },
    default = auto,
  },
  math-font = {
    name = math@font,
    choices = {
      xits,
      stix,
      libertinus,
      lm,
      none,
    },
    default = xits,
  },
}

% 处理 \opt{fontset}
\ifclass@fontset@mac
  \classsetup{
    font     = times,
    cjk-font = mac,
  }
\else
  \ifclass@fontset@windows
    \classsetup{
      font     = times,
      cjk-font = windows,
    }
  \else
    \ifclass@fontset@fandol
      \classsetup{
        font     = xits,
        cjk-font = fandol,
      }
    \else
      \ifclass@fontset@ubuntu
        \classsetup{
          font     = xits,
          cjk-font = noto,
        }
      \fi
    \fi
  \fi
\fi

% 检测系统
\class@define@key{
  system = {
    choices = {
      auto,
      mac,
      unix,
      windows,
    },
    default = auto,
  },
}
\ifclass@system@auto
  \IfFileExists{/System/Library/Fonts/Menlo.ttc}{
    \classsetup{system = mac}
  }{
    \IfFileExists{/dev/null}{
      \IfFileExists{null:}{
        \classsetup{system = windows}
      }{
        \classsetup{system = unix}
      }
    }{
      \classsetup{system = windows}
    }
  }
\fi

% XITS 字体于 2018-10-03 更改了字体的文件名，所以需要判断。
% 原文件名为 \file{xits-regular.otf}、\file{xits-math.otf} 等，
% 后改为 \file{XITS-Regular.otf}、\file{XITSMath-Regular.otf} 等。
\let\class@font@family@xits\@empty
\newcommand\class@set@xits@names{%
  \ifx\class@font@family@xits\@empty
    \IfFontExistsTF{XITSMath-Regular.otf}{%
      \gdef\class@font@family@xits{XITS}%
      \gdef\class@font@style@xits@rm{Regular}%
      \gdef\class@font@style@xits@bf{Bold}%
      \gdef\class@font@style@xits@it{Italic}%
      \gdef\class@font@style@xits@bfit{BoldItalic}%
      \gdef\class@font@name@xits@math@rm{XITSMath-Regular}%
      \gdef\class@font@name@xits@math@bf{XITSMath-Bold}%
    }{%
      \gdef\class@font@family@xits{xits}%
      \gdef\class@font@style@xits@rm{regular}%
      \gdef\class@font@style@xits@bf{bold}%
      \gdef\class@font@style@xits@it{italic}%
      \gdef\class@font@style@xits@bfit{bolditalic}%
      \gdef\class@font@name@xits@math@rm{xits-math}%
      \gdef\class@font@name@xits@math@bf{xits-mathbold}%
    }%
  \fi
}

% Libertinus 字体同样。
\let\class@font@family@libertinus\@empty
\newcommand\class@set@libertinus@names{%
  \ifx\class@font@family@libertinus\@empty
    \IfFontExistsTF{LibertinusSerif-Regular.otf}{%
      \gdef\class@font@family@libertinus@serif{LibertinusSerif}%
      \gdef\class@font@family@libertinus@sans{LibertinusSans}%
      \gdef\class@font@name@libertinus@math{LibertinusMath-Regular}%
      \gdef\class@font@style@libertinus@rm{Regular}%
      \gdef\class@font@style@libertinus@bf{Bold}%
      \gdef\class@font@style@libertinus@it{Italic}%
      \gdef\class@font@style@libertinus@bfit{BoldItalic}%
    }{%
      \gdef\class@font@family@libertinus@serif{libertinusserif}%
      \gdef\class@font@family@libertinus@sans{libertinussans}%
      \gdef\class@font@name@libertinus@math{libertinusmath-regular}%
      \gdef\class@font@style@libertinus@rm{regular}%
      \gdef\class@font@style@libertinus@bf{bold}%
      \gdef\class@font@style@libertinus@it{italic}%
      \gdef\class@font@style@libertinus@bfit{bolditalic}%
    }%
  \fi
}

% 西文字体
\ifclass@font@auto
  \ifclass@system@unix
    \classsetup{font=xits}
  \else
    \classsetup{font=times}
  \fi
\fi
\newcommand\class@load@font@times{%
  \setmainfont{Times New Roman}%
  \setsansfont{Arial}[Scale = MatchLowercase]%
  \ifclass@system@mac
    \setmonofont{Menlo}[Scale = MatchLowercase]%
  \else
    \setmonofont{Courier New}[Scale = MatchLowercase]%
  \fi
}
\newcommand\class@load@font@termes{%
  \setmainfont{texgyretermes}[
    Extension      = .otf,
    UprightFont    = *-regular,
    BoldFont       = *-bold,
    ItalicFont     = *-italic,
    BoldItalicFont = *-bolditalic,
  ]%
  \class@load@texgyre@sans@mono
}
\newcommand\class@load@texgyre@sans@mono{%
  \setsansfont{texgyreheros}[
    Extension      = .otf,
    UprightFont    = *-regular,
    BoldFont       = *-bold,
    ItalicFont     = *-italic,
    BoldItalicFont = *-bolditalic,
    Scale          = MatchLowercase,
  ]%
  \setmonofont{texgyrecursor}[
    Extension      = .otf,
    UprightFont    = *-regular,
    BoldFont       = *-bold,
    ItalicFont     = *-italic,
    BoldItalicFont = *-bolditalic,
    Scale          = MatchLowercase,
  ]%
}
\newcommand\class@load@font@xits{%
  \class@set@xits@names
  \setmainfont{\class@font@family@xits}[
    Extension      = .otf,
    UprightFont    = *-\class@font@style@xits@rm,
    BoldFont       = *-\class@font@style@xits@bf,
    ItalicFont     = *-\class@font@style@xits@it,
    BoldItalicFont = *-\class@font@style@xits@bfit,
  ]%
  \class@load@texgyre@sans@mono
}
\newcommand\class@load@font@libertinus{%
  \class@set@libertinus@names
  \setmainfont{\class@font@family@libertinus@serif}[
    Extension      = .otf,
    UprightFont    = *-\class@font@style@libertinus@rm,
    BoldFont       = *-\class@font@style@libertinus@bf,
    ItalicFont     = *-\class@font@style@libertinus@it,
    BoldItalicFont = *-\class@font@style@libertinus@bfit,
  ]%
  \setsansfont{\class@font@family@libertinus@sans}[
    Extension      = .otf,
    UprightFont    = *-\class@font@style@libertinus@rm,
    BoldFont       = *-\class@font@style@libertinus@bf,
    ItalicFont     = *-\class@font@style@libertinus@it,
    Scale          = MatchLowercase,
  ]%
  \setmonofont{lmmonolt10}[
    Extension      = .otf,
    UprightFont    = *-regular,
    BoldFont       = *-bold,
    ItalicFont     = *-oblique,
    BoldItalicFont = *-boldoblique,
    Scale          = MatchLowercase,
  ]%
}
\newcommand\class@load@font@lm{%
  \setmainfont{lmroman10}[
    Extension      = .otf,
    UprightFont    = *-regular,
    BoldFont       = *-bold,
    ItalicFont     = *-italic,
    BoldItalicFont = *-bolditalic,
  ]%
  \setsansfont{lmsans10}[
    Extension      = .otf,
    UprightFont    = *-regular,
    BoldFont       = *-bold,
    ItalicFont     = *-oblique,
    BoldItalicFont = *-boldoblique,
  ]%
  \setmonofont{lmmonolt10}[
    Extension      = .otf,
    UprightFont    = *-regular,
    BoldFont       = *-bold,
    ItalicFont     = *-oblique,
    BoldItalicFont = *-boldoblique,
  ]%
}
\newcommand\class@load@font{%
  \@nameuse{class@load@font@\class@font}%
}
\class@load@font
\class@option@hook{font}{\class@load@font}

% 中文字体
\ifclass@cjk@font@auto
  \ifclass@system@mac
    \classsetup{cjk-font = mac}
  \else
    \ifclass@system@windows
      \classsetup{cjk-font = windows}
    \else
      \IfFontExistsTF{Noto Serif CJK SC}{
        \classsetup{cjk-font = noto}
      }{
        \classsetup{cjk-font = fandol}
      }
    \fi
  \fi
\fi
\newcommand\class@load@cjk@font@windows{%
  \xeCJKsetup{EmboldenFactor=2}
  \setCJKmainfont{SimSun}[
    AutoFakeBold = true,
    ItalicFont   = KaiTi,
  ]%
  \setCJKsansfont{SimHei}[AutoFakeBold]%
  \setCJKmonofont{FangSong}%
  \setCJKfamilyfont{zhsong}{SimSun}[AutoFakeBold]%
  \setCJKfamilyfont{zhhei}{SimHei}[AutoFakeBold]%
  \setCJKfamilyfont{zhkai}{KaiTi}%
  \setCJKfamilyfont{zhfs}{FangSong}%
}
\newcommand\class@load@cjk@font@mac{%
  \setCJKmainfont{Songti SC}[
    UprightFont    = * Light,
    BoldFont       = * Bold,
    ItalicFont     = Kaiti SC,
    BoldItalicFont = Kaiti SC Bold,
  ]%
  \setCJKsansfont{Heiti SC}[BoldFont=* Medium]%
  \setCJKmonofont{STFangsong}
  \setCJKfamilyfont{zhsong}{Songti SC}[
    UprightFont = * Light,
      BoldFont  = * Bold,
  ]%
  \setCJKfamilyfont{zhhei}{Heiti SC}[
    UprightFont = * Light,
    BoldFont    = * Medium,
  ]%
  \setCJKfamilyfont{zhfs}{STFangsong}%
  \setCJKfamilyfont{zhkai}{Kaiti SC}[BoldFont = * Bold]%
  \setCJKfamilyfont{zhli}{Baoli SC}%
  \setCJKfamilyfont{zhyuan}{Yuanyi SC}[
    UprightFont = * Light,
    BoldFont    = * Bold,
  ]%
  \xeCJKsetwidth{‘’“”}{1em}%
}

% 注意 Noto CJK 的 regular 字重名字不带“Regular”。
\newcommand\class@load@cjk@font@noto{%
  \setCJKmainfont{Noto Serif CJK SC}[
    UprightFont    = * Light,
    BoldFont       = * Bold,
    ItalicFont     = FandolKai-Regular,
    ItalicFeatures = {Extension = .otf},
  ]%
  \setCJKsansfont{Noto Sans CJK SC}[
    BoldFont    = * Medium,
  ]%
  \setCJKmonofont{Noto Sans Mono CJK SC}%
  \setCJKfamilyfont{zhsong}{Noto Serif CJK SC}[
    UprightFont = * Light,
    UprightFont = * Bold,
  ]%
  \setCJKfamilyfont{zhhei}{Noto Sans CJK SC}[
    BoldFont    = * Medium,
  ]%
  \setCJKfamilyfont{zhfs}{FandolFang}[
    Extension   = .otf,
    UprightFont = *-Regular,
  ]%
  \setCJKfamilyfont{zhkai}{FandolKai}[
    Extension   = .otf,
    UprightFont = *-Regular,
  ]%
}
\newcommand\class@load@cjk@font@fandol{%
  \setCJKmainfont{FandolSong}[
    Extension   = .otf,
    UprightFont = *-Regular,
    BoldFont    = *-Bold,
    ItalicFont  = FandolKai-Regular,
  ]%
  \setCJKsansfont{FandolHei}[
    Extension   = .otf,
    UprightFont = *-Regular,
    BoldFont    = *-Bold,
  ]%
  \setCJKmonofont{FandolFang}[
    Extension   = .otf,
    UprightFont = *-Regular,
  ]%
  \setCJKfamilyfont{zhsong}{FandolSong}[
    Extension   = .otf,
    UprightFont = *-Regular,
    BoldFont    = *-Bold,
  ]%
  \setCJKfamilyfont{zhhei}{FandolHei}[
    Extension   = .otf,
    UprightFont = *-Regular,
    BoldFont    = *-Bold,
  ]%
  \setCJKfamilyfont{zhfs}{FandolFang}[
    Extension   = .otf,
    UprightFont = *-Regular,
  ]%
  \setCJKfamilyfont{zhkai}{FandolKai}[
    Extension   = .otf,
    UprightFont = *-Regular,
  ]%
}
\ifclass@cjk@font@none\else
  \providecommand\songti{\CJKfamily{zhsong}}
  \providecommand\heiti{\CJKfamily{zhhei}}
  \providecommand\fangsong{\CJKfamily{zhfs}}
  \providecommand\kaishu{\CJKfamily{zhkai}}
\fi
\newcommand\class@load@cjk@font{%
  \@nameuse{class@load@cjk@font@\class@cjk@font}%
}
\class@load@cjk@font
\class@option@hook{cjk-font}{\class@load@cjk@font}

% 使用 \pkg{unicode-math} 配置数学字体。
\unimathsetup{
  math-style = ISO,
  bold-style = ISO,
  nabla      = upright,
  partial    = upright,
}

\newcommand\class@load@math@font@xits{%
  \class@set@xits@names
  \setmathfont{\class@font@name@xits@math@rm}[
    Extension    = .otf,
    BoldFont     = \class@font@name@xits@math@bf,
    StylisticSet = 8,
  ]%
  \setmathfont{\class@font@name@xits@math@rm}[
    Extension    = .otf,
    StylisticSet = 1,
    range        = {cal,bfcal},
  ]%
}
\newcommand\class@load@math@font@stix{%
  \setmathfont{STIX2Math}[
    Extension    = .otf,
    StylisticSet = 8,
  ]%
  \setmathfont{STIX2Math}[
    Extension    = .otf,
    StylisticSet = 1,
    range        = {cal,bfcal},
  ]%
}
\newcommand\class@load@math@font@libertinus{%
  \class@set@libertinus@names
  \setmathfont{\class@font@name@libertinus@math .otf}%
}
\newcommand\class@load@math@font@lm{%
  \setmathfont{latinmodern-math.otf}%
}
\newcommand\class@load@math@font{%
  \csname class@load@math@font@\class@math@font\endcsname
}
\class@load@math@font
\class@option@hook{math-font}{\class@load@math@font}

% 字号
% 基本行距是字号的 1.2 倍
\renewcommand\normalsize{%
  % \@setfontsize\normalsize\@xpt\@xiipt
  \@setfontsize\normalsize{9.95bp}{11.94bp}%
  % \abovedisplayskip 10\p@ \@plus2\p@ \@minus5\p@
  \abovedisplayskip 6\p@ \@plus\p@ \@minus\p@
  \abovedisplayshortskip \z@ \@plus3\p@
  \belowdisplayshortskip 6\p@ \@plus3\p@ \@minus3\p@
  \belowdisplayskip \abovedisplayskip
  \let\@listi\@listI}
\ifx\MakeRobust\@undefined \else
  \MakeRobust\normalsize
\fi
\DeclareRobustCommand\small{%
  % \@setfontsize\small\@ixpt{11}%
  \@setfontsize\small{9bp}{10.8bp}%
  % \abovedisplayskip 8.5\p@ \@plus3\p@ \@minus4\p@
  \abovedisplayskip 5.1\p@ \@plus\p@ \@minus\p@
  \abovedisplayshortskip \z@ \@plus2\p@
  \belowdisplayshortskip 4\p@ \@plus2\p@ \@minus2\p@
  \belowdisplayskip \abovedisplayskip
}
\DeclareRobustCommand\footnotesize{%
  % \@setfontsize\footnotesize\@viiipt{9.5}%
  \@setfontsize\footnotesize{7.5bp}{9.5bp}%
  % \abovedisplayskip 6\p@ \@plus2\p@ \@minus4\p@
  \abovedisplayskip 4\p@ \@plus\p@ \@minus\p@
  \abovedisplayshortskip \z@ \@plus\p@
  \belowdisplayshortskip 3\p@ \@plus\p@ \@minus2\p@
  \belowdisplayskip \abovedisplayskip
}

% \addtolength{\thinmuskip}{-1mu}
% \addtolength{\medmuskip}{-2mu}
% \addtolength{\thickmuskip}{-2mu}

% 设置行距的倍数为 1.25。
% 实际行距是字号的 1.2 * 1.25 = 1.5 倍。
\linespread{1.25}\selectfont

%--------------------------------- 正文 ------------------------------------

\newcommand\class@set@names{%
  \ifclass@language@chinese
    \ctexset{
      appendixname = {附录},
      contentsname = {目录},
      figurename   = {图},
      tablename    = {表},
      bibname      = {参考文献},
      indexname    = {索引},
      autoindent   = 2,
    }%
  \else
    \ctexset{
      appendixname = {Appendix},
      contentsname = {Contents},
      figurename   = {Fig.},
      tablename    = {Table},
      bibname      = {References},
      indexname    = {Index},
      autoindent   = 2,
    }%
  \fi
}
\class@set@names
\class@option@hook{language}{\class@set@names}

% 调整列表中各项之间过大的间距。
\setlength\partopsep{\z@}
\newcommand\class@nolistsep{%
  \parsep 0\p@ \@plus.2\p@
  \topsep 0\p@ \@plus.2\p@
  \itemsep0\p@ \@plus.2\p@
}
\def\@listi{\leftmargin\leftmargini
            \class@nolistsep}
\let\@listI\@listi
\@listi
\def\@listii {\leftmargin\leftmarginii
              \labelwidth\leftmarginii
              \advance\labelwidth-\labelsep
              \class@nolistsep}
\def\@listiii{\leftmargin\leftmarginiii
              \labelwidth\leftmarginiii
              \advance\labelwidth-\labelsep
              \class@nolistsep}

% 设置 url 的样式
\urlstyle{same}

\def\UrlBreaks{%
  \do\/%
  \do\a\do\b\do\c\do\d\do\e\do\f\do\g\do\h\do\i\do\j\do\k\do\l%
     \do\m\do\n\do\o\do\p\do\q\do\r\do\s\do\t\do\u\do\v\do\w\do\x\do\y\do\z%
  \do\A\do\B\do\C\do\D\do\E\do\F\do\G\do\H\do\I\do\J\do\K\do\L%
     \do\M\do\N\do\O\do\P\do\Q\do\R\do\S\do\T\do\U\do\V\do\W\do\X\do\Y\do\Z%
  \do0\do1\do2\do3\do4\do5\do6\do7\do8\do9\do=\do/\do.\do:%
  \do\*\do\-\do\~\do\'\do\"\do\-}

\DeclareRobustCommand\doi[1]{%
  \edef\class@@url@tmp{#1}%
  \expandafter\@doi\expandafter{\class@@url@tmp}%
}
\DeclareUrlCommand\@doi{\urlstyle{rm}}
\DeclareRobustCommand\email[1]{%
  \edef\class@@url@tmp{#1}%
  \expandafter\@email\expandafter{\class@@url@tmp}%
}
\DeclareUrlCommand\@email{\urlstyle{rm}}

%---------------------------------- 数学符号 ---------------------------------

% 小于等于号、大于等于号要使用倾斜的字形。
\protected\def\le{\leqslant}
\protected\def\ge{\geqslant}
\AtBeginDocument{%
  \renewcommand\leq{\leqslant}%
  \renewcommand\geq{\geqslant}%
}

% 积分号的上下限默认置于上下两侧。
\removenolimits{%
  \int\iint\iiint\iiiint\oint\oiint\oiiint
  \intclockwise\varointclockwise\ointctrclockwise\sumint
  \intbar\intBar\fint\cirfnint\awint\rppolint
  \scpolint\npolint\pointint\sqint\intlarhk\intx
  \intcap\intcup\upint\lowint
}

% 实部、虚部操作符使用罗马体 $\mathrm{Re}$、$\mathrm{Im}$ 而不是 fraktur 体
% $\Re$、$\Im$。
\AtBeginDocument{%
  \renewcommand\Re{\operatorname{Re}}%
  \renewcommand\Im{\operatorname{Im}}%
}

% 兼容旧的粗体命令：\pkg{bm} 的 \cs{bm} 和 \pkg{amsmath} 的 \cs{boldsymbol}。
\DeclareRobustCommand\bm[1]{{\symbf{#1}}}
\DeclareRobustCommand\boldsymbol[1]{{\symbf{#1}}}

% 兼容 \pkg{amssymb} 中的命令。
\newcommand\square{\mdlgwhtsquare}
\newcommand\blacksquare{\mdlgblksquare}
\AtBeginDocument{%
  \renewcommand\checkmark{\ensuremath{✓}}%
}

%---------------------------------- pagestyle ---------------------------------

\pagestyle{fancy}

\newcommand\class@format@date[2]{%
  \edef\class@@date{#2}%
  \def\class@@process@date##1-##2-##3\@nil{%
    #1{##1}{##2}{##3}%
  }%
  \expandafter\class@@process@date\class@@date\@nil
}
\newcommand\class@date@zh@short[1]{%
  \def\class@@format##1##2##3{%
    ##1\;年\;\number##2\;月%
  }%
  \class@format@date{\class@@format}{#1}%
}
\newcommand\class@short@month[1]{%
  \ifcase\number#1\relax
    XXX.\or
    Jan.\or Feb.\or Mar.\or Apr.\or May\or Jun.\or
    Jul.\or Aug.\or Sep.\or Oct.\or Nov.\or Dec.%
  \fi
}%
\newcommand\class@date@en[1]{%
  \def\class@@format##1##2##3{%
    ##3 \class@short@month{##2} ##1%
  }%
  \class@format@date{\class@@format}{#1}%
}

\newcommand\class@date@en@short[1]{%
  \def\class@@format##1##2##3{%
    \class@short@month{##2}\,, ##1%
  }%
  \class@format@date{\class@@format}{#1}%
}

\fancypagestyle{title}{%
  \fancyhf{}%
  \fancyhead[L]{%
    \zihao{-5}%
    \quad 第 \class@volume{} 卷\;第 \class@number{} 期\\[4pt]%
    \quad \class@date@zh@short{\class@publish@date}%
  }%
  \fancyhead[R]{%
    \zihao{-5}%
    Vol. \class@volume, No. \class@number\mbox{\hspace{1em}}\\[4pt]%
    \class@date@en@short{\class@publish@date}\quad
  }%
  \fancyhead[C]{%
    \normalsize 原~~子~~核~~物~~理~~评~~论\\[4pt]%
    \zihao{-5}Nuclear~ Physics~ Review%
  }%
  \renewcommand{\headrule}{%
    \vskip 2pt%
    \hrule height0.4pt width\headwidth \vskip1pt%
    \hrule height0.4pt width\headwidth \vskip-1.8pt%
  }%
}

\newcommand\class@format@short@names{%
  \let\class@@tmp\@empty
  \let\class@@et@al\@empty
  \kv@set@family@handler{class@authors}{%
    \kvsetkeys{class@author}{##2}%
    \ifx\class@@tmp\@empty
      \let\class@@tmp\class@@name@main
      \class@@name@main
    \else
      \ifx\class@@et@al\@empty
        \let\class@@et@al\class@@name@main
        \ifclass@language@chinese
          等%
        \else
          \space\textit{et al}%
        \fi
      \fi
    \fi
  }%
  \kvsetkeys@expandafter{class@authors}{\class@authors}%
}

\AtBeginDocument{
  \setcounter{page}{\class@page}
}

\fancypagestyle{plain}{%
  \fancyhf{}%
  \fancyhead[LO]{\zihao{-5}\hspace{0.5em}第\;\class@number\;期\hspace{0.5em}}%
  \fancyhead[CO]{%
    \zihao{-5}\class@format@short@names
    \ifclass@language@chinese
      ：%
    \else
      :\space
    \fi
    \ifx\class@short@title\@empty
      \class@title
    \else
      \class@short@title
    \fi
  }%    %奇页页眉
  \fancyhead[RO,LE]{%
    \zihao{-5}\hspace{0.5em}\textbf{\textperiodcentered}\;\thepage\;\textbf{\textperiodcentered}\hspace{0.5em}}%
  \fancyhead[CE]{\zihao{-5}原~~子~~核~~物~~理~~评~~论}%
  \fancyhead[RE]{\zihao{-5}\hspace{0.5em}第\;\class@volume\;卷\hspace{0.5em}}%
  \renewcommand{\headrule}{%
    \vskip 2pt%
    \hrule height0.4pt width\headwidth
    \vskip -0.4pt%
  }%
}

\pagestyle{plain}

%----------------------------------\thanks, \footnote--------------------------------------

\setlength\footnotesep{8pt}  %

\renewcommand\footnoterule{%
  \kern 1\p@
  \hrule \@width37mm
  \kern 8\p@}


% 封面

\class@define@key{
  title = {
    default = {标题},
  },
  title* = {
    default = {Title},
    name    = title@alt,
  },
  short-title = {
    name = short@title,
  },
  authors = {},
  affiliations = {},
  abstract = {
    default = {摘要内容},
  },
  abstract* = {
    default = {Abstract content},
    name    = abstract@alt,
  },
  keywords = {},
  keywords* = {
    name    = keywords@alt,
  },
  clc = {
    default = {O571.53},
  },
  document-code = {
    name    = document@code,
    default = {A},
  },
  doi = {
    default = {10.11804/NuclPhysRev.\two@digits{\class@volume}.01.\two@digits{\thepage}},
  },
  received-date = {
    name = received@date,
    default = {\the\year-\two@digits{\month}-\two@digits{\day}},
  },
  revised-date = {
    name = revised@date,
    default = {\the\year-\two@digits{\month}-\two@digits{\day}},
  },
  grants  = {},
  grants* = {
    name = grants@alt,
  },
  publish-date = {
    name = publish@date,
    default = {\the\year-\two@digits{\month}-\two@digits{\day}},
  },
  volume = {
    default = {31},
  },
  number = {
    default = {1},
  },
  page = {
    default = {1},
  },
  article-id = {
    name    = article@id,
    default = {%
      1007-4627(\number\year)\,\two@digits{\class@number}-%
      \class@four@digits{\c@page}-%
      \two@digits{\the\numexpr\getpagerefnumber{LastPage}-\thepage+1}%
    },
  },
}

% 主标题
\renewcommand\maketitle{\par%
  \begingroup
    % \renewcommand\thefootnote{\@fnsymbol\c@footnote}%
    % \def\@makefnmark{\rlap{\@textsuperscript{\normalfont\@thefnmark}}}%
    \let\@makefnmark\relax
    % \long\def\@makefntext##1{\parindent 1em\noindent
    %         \hb@xt@1.8em{%
    %             \hss\@textsuperscript{\normalfont\@thefnmark}}##1}%
    \long\def\@makefntext##1{%
      \fontsize{8bp}{9.6bp}\selectfont
      \@setpar{\@@par
        \@tempdima = \hsize
        \advance\@tempdima-5em%
        \parshape \@ne 5em \@tempdima}%
        \par
        \parindent -5em
        ##1%
    }%
    \if@twocolumn
      \ifnum \col@number=\@ne
        \@maketitle
      \else
        \twocolumn[\@maketitle]%
      \fi
    \else
      \newpage
      \global\@topnum\z@   % Prevents figures from going at top of page.
      \@maketitle
    \fi
    % \thispagestyle{plain}\@thanks
    \thispagestyle{title}%
    \class@title@footnote@main
  \endgroup
  \setcounter{footnote}{0}%
  \global\let\thanks\relax
  \global\let\maketitle\maketitlealt
  \global\let\@maketitle\relax
  \global\let\@thanks\@empty
  \global\let\@author\@empty
  \global\let\@date\@empty
  \global\let\@title\@empty
  \global\let\title\relax
  \global\let\author\relax
  \global\let\date\relax
  \global\let\and\relax
}

\renewcommand\@maketitle{%
  \newpage
  % \null
  % \vskip 2em%
  \begin{center}%
    \let \footnote \thanks
    \parbox{166mm}{%
      \ifclass@language@chinese
        \textsf{文章编号}：\quad
        {\zihao{-5}\class@article@id}\par
      \else
        \textbf{Article ID:}\quad
        {\zihao{-5}\class@article@id}\par
      \fi
    }\par
    \vskip 4mm%
    % {\LARGE \@title \par}%
    \begingroup
      \ifclass@language@chinese
        \sffamily
      \else
        \bfseries
      \fi
      \fontsize{16.5bp}{19.8bp}\selectfont
      \class@title\par
    \endgroup
    % \vskip 1.5em%
    \vskip 5mm%
    % {\large
    %   \lineskip .5em%
    %   \begin{tabular}[t]{c}%
    %     \@author
    %   \end{tabular}\par}%
    \begingroup
      \fangsong\fontsize{11bp}{13.2bp}\selectfont
      \class@format@authors{main}\par
    \endgroup
    \vspace{2mm}%
    \begingroup
      \zihao{-5}%
      \class@format@affiliations{main}\par
    \endgroup
    \vspace{4mm}%
    \parbox{166mm}{%
      \ifclass@language@chinese
        \textsf{摘要：}{\fangsong\class@abstract}\par
        \textsf{关键词：}{\fangsong\class@clist@use{\class@keywords}{；}}\par
      \else
        \textbf{Abstract:} \class@abstract\par
        \textbf{Key words:} \class@clist@use{\class@keywords}{; }\par
      \fi
      \ifclass@language@chinese
        \textsf{中图分类号：}\class@clc\qquad
        \textsf{文献标志码：}\class@document@code\qquad
        \textbf{DOI：}\doi{\class@doi}%
      \else
        \textbf{CLC number:}\quad\class@clc\qquad
        \textbf{Document code:}\quad\class@document@code\qquad
        \textbf{DOI:}\quad\doi{\class@doi}%
      \fi
      \par
    }%
  \end{center}%
  \par
  \vskip 9mm%
}%

% 副标题
\newcommand\maketitlealt{\par%
  \begingroup
    % \renewcommand\thefootnote{\@fnsymbol\c@footnote}%
    % \def\@makefnmark{\rlap{\@textsuperscript{\normalfont\@thefnmark}}}%
    \let\@makefnmark\relax
    % \long\def\@makefntext##1{\parindent 1em\noindent
    %         \hb@xt@1.8em{%
    %             \hss\@textsuperscript{\normalfont\@thefnmark}}##1}%
    \long\def\@makefntext##1{%
      \fontsize{8bp}{9.6bp}\selectfont
      \@setpar{\@@par
        \@tempdima = \hsize
        \advance\@tempdima-5em%
        \parshape \@ne 5em \@tempdima}%
        \par
        \parindent -5em
        ##1%
    }%
    \newpage
    \onecolumn
    \global\@topnum\z@   % Prevents figures from going at top of page.
    \ifclass@language@chinese
      \classsetup{language = english}
    \else
      \classsetup{language = chinese}
    \fi
    \@maketitle@alt
    % \thispagestyle{plain}\@thanks
    \class@title@footnote@alt
    \class@reset@main@language
  \endgroup
  \setcounter{footnote}{0}%
  \global\let\thanks\relax
  \global\let\maketitle\relax
  \global\let\@maketitle@alt\relax
  \global\let\@thanks\@empty
  \global\let\@author\@empty
  \global\let\@date\@empty
  \global\let\@title\@empty
  \global\let\title\relax
  \global\let\author\relax
  \global\let\date\relax
  \global\let\and\relax
}

\newcommand\@maketitle@alt{%
  \newpage
  % \null
  % \vskip 2em%
  \begin{center}%
    \let \footnote \thanks
    % {\LARGE \@title \par}%
    \begingroup
      \ifclass@language@chinese
        \sffamily
      \else
        \bfseries
      \fi
      \fontsize{14.5bp}{17.4bp}\selectfont
      \class@title@alt\par
    \endgroup
    % \vskip 1.5em%
    \vskip 5mm%
    % {\large
    %   \lineskip .5em%
    %   \begin{tabular}[t]{c}%
    %     \@author
    %   \end{tabular}\par}%
    \begingroup
      \fangsong\fontsize{11bp}{13.2bp}\selectfont
      \class@format@authors{alt}\par
    \endgroup
    \vspace{2mm}%
    \begingroup
      \zihao{-5}%
      \class@format@affiliations{alt}\par
    \endgroup
    \vspace{4mm}%
    \parbox{166mm}{%
      \ifclass@language@chinese
        \textsf{摘要：}{\fangsong\class@abstract@alt}\par
        \textsf{关键词：}{\fangsong\class@clist@use{\class@keywords@alt}{；}}\par
      \else
        \textbf{Abstract:} \class@abstract@alt\par
        \textbf{Key words:} \class@clist@use{\class@keywords@alt}{; }\par
      \fi
      \par
    }%
  \end{center}%
  \par
  \vskip 5mm%
}

\newcommand\class@four@digits[1]{%
  \ifnum#1<10\relax
    000%
  \else
    \ifnum#1<100\relax
      00%
    \else
      \ifnum#1<1000\relax
        0%
      \fi
    \fi
  \fi
  \number#1%
}

% 处理中文姓名格式
\newbox\class@@box
\newcommand\class@format@name@zh[1]{%
  \sbox\class@@box{#1}%
  \ifdim\wd\class@@box<2.1em\relax
    \ifdim\wd\class@@box>1.5em\relax
      \begingroup
        \def\CJKglue{\hskip 0pt plus 2filll}%
        \makebox[2.16667em][l]{#1}%
      \endgroup
    \else
      #1%
    \fi
  \else
    #1%
  \fi
}

\newcommand\class@format@name@en[1]{#1}

\newcommand\class@clist@use[2]{%
  \begingroup
    \def\class@@tmp{}%
    \kv@set@family@handler{class@clist}{%
      \ifx\class@@tmp\@empty
        \def\class@@tmp{#2}%
      \else
        #2%
      \fi
      ##1%
    }%
    \kvsetkeys@expandafter{class@clist}{#1}%
  \endgroup
}

\newcommand\class@valid@affiliations{}
\def\class@@tmp@affil{}
\newcounter{class@affil@count}
\kv@set@family@handler{class@affil@number}{%
  \expandafter\ifx\csname class@affil@number@#1\endcsname\relax
    \stepcounter{class@affil@count}%
    \expandafter\xdef\csname class@affil@number@#1\endcsname{%
      \the\c@class@affil@count
    }%
    \g@addto@macro\class@valid@affiliations{#1,}%
  \fi
  \ifx\class@@tmp@affil\@empty
    \def\class@@tmp@affil{1}%
  \else
    ,\space
  \fi
  \csname class@affil@number@#1\endcsname
}

\newcommand\class@format@affil@numbers[1]{%
  % \kvsetkeys@expandafter{class@affil@number}{#1}%
  \def\class@@tmp@affil{}%
  \kvsetkeys@expandafter{class@affil@number}{#1}%
}

\newif\ifclass@@corresponding
\kv@define@key{class@author}{name}{\def\class@@name@main{#1}}
\kv@define@key{class@author}{name*}{\def\class@@name@alt{#1}}
\kv@define@key{class@author}{affiliations}{\def\class@@affils{#1}}
\kv@define@key{class@author}{biography}{\def\class@@biography{#1}}
\kv@define@key{class@author}{email}{\def\class@@email{#1}}
\kv@define@key{class@author}{corresponding}[false]{%
  \@nameuse{class@@corresponding#1}%
}

% 选择 main 或者 alternative
\newcommand\class@format@authors[1]{%
  \let\class@@tmp\@empty
  \kv@set@family@handler{class@authors}{%
    \kvsetkeys{class@author}{##2}%
    \ifx\class@@tmp\@empty
      \def\class@@tmp{1}%
    \else
      \ifclass@language@chinese
        ，%
      \else
        ,\space
      \fi
    \fi
    \ifclass@language@chinese
      \class@format@name@zh{\@nameuse{class@@name@#1}}%
    \else
      \class@format@name@en{\@nameuse{class@@name@#1}}%
    \fi
    \ignorespaces
    \textsuperscript{\class@format@affil@numbers{\class@@affils}}%
  }%
  \kvsetkeys@expandafter{class@authors}{\class@authors}%
}

\kv@define@key{class@affiliation}{name}{\def\class@@affil@main{#1}}
\kv@define@key{class@affiliation}{name*}{\def\class@@affil@alt{#1}}

% 选择 main 或者 alt
\newcommand\class@format@affiliations[1]{%
  \def\class@@tmp{}%
  \kv@set@family@handler{class@affiliations}{%
    \ifx\class@@tmp\@empty
      \def\class@@tmp{1}%
    \else
      \ifclass@language@chinese
        ；\\%
      \else
        ;\\%
      \fi
    \fi
    \csname class@affil@number@##1\endcsname.\space
    \kvsetkeys{class@affiliation}{##2}%
    \@nameuse{class@@affil@#1}%
    % \expandafter\show\csname class@@affil@#1\endcsname
  }%
  (\,%
  \begingroup
    \ifclass@language@english
      \itshape
    \fi
    \kvsetkeys@expandafter{class@affiliations}{\class@affiliations}%
  \endgroup
  \,)%
}

% 标题页的脚注
\newcommand\class@title@footnote@main{%
  \let\class@@first@author\@empty
  \kv@set@family@handler{class@authors}{%
    \class@@correspondingfalse
    \kvsetkeys{class@author}{##2}%
    \ifx\class@@first@author\@empty
      \def\class@@first@author{##1}%
      \ifclass@language@chinese
        \textsf{作者简介：}\class@@biography
      \else
        \textbf{Biography:}\space\class@@biography
      \fi
      \ifx\class@@email\@empty\else
        ；E-mail: \email{\class@@email}%
      \fi
    \else
      \ifclass@@corresponding
        \par
        \ifclass@language@chinese
          \textsf{通信作者：}E-mail: \email{\class@@email}%
        \else
          \textbf{Corresponding author:} E-mail: \email{\class@@email}%
        \fi
      \fi
    \fi
  }%
  \footnotetext{%
    \ifclass@language@chinese
      \textsf{收稿日期：}\class@received@date ；\quad
      \textsf{修改日期：}\class@revised@date\par
      \textsf{基金项目：}\class@grants\par
    \else
      \textbf{Received date:} \class@date@en{\class@received@date};\quad
      \textbf{Revised date:} \class@date@en{\class@revised@date}\par
      \textbf{Foundation item:} \class@grants\par
    \fi
    \kvsetkeys@expandafter{class@authors}{\class@authors}%
  }%
}

\newcommand\class@title@footnote@alt{%
  \kv@set@family@handler{class@authors}{%
    \class@@correspondingfalse
    \kvsetkeys{class@author}{##2}%
    \ifclass@@corresponding
      \par
      \ifclass@language@chinese
        \textsf{通信作者：}\class@@name@alt，E-mail: \email{\class@@email}%
      \else
        \textbf{Corresponding author:} \class@@name@alt,\space
        E-mail: \email{\class@@email}%
      \fi
    \fi
  }%
  \footnotetext{%
    \ifclass@language@chinese
      \textsf{收稿日期：}\class@received@date ；\quad
      \textsf{修改日期：}\class@revised@date\par
      \textsf{基金项目：}\class@grants@alt\par
    \else
      \textbf{Received date:} \class@date@en{\class@received@date};\quad
      \textbf{Revised date:} \class@date@en{\class@revised@date}\par
      \textbf{Foundation item:} \class@grants@alt\par
    \fi
    \kvsetkeys@expandafter{class@authors}{\class@authors}%
  }%
}

%-------------------------------- 章节标题 -------------------------------------

\ctexset{
  section = {
    format      = {\sffamily\fontsize{12.7bp}{15.24bp}\selectfont},
    beforeskip  = 3mm \@plus.25ex \@minus .25ex,
    afterskip   = 2.5mm \@plus.25ex \@minus .25ex,
    afterindent = true,
  },
  subsection = {
    format     = {\sffamily\zihao{5}},
    beforeskip = 1.1ex \@plus .15ex,
    afterskip  = 0.9ex \@plus .15ex,
    afterindent = true,
  },
  subsubsection = {
    format     = {\sffamily\zihao{5}},
    beforeskip = 0.5ex,
    afterskip  = 0.5ex,
    afterindent = true,
  },
}

%--------------------------------- 浮动体 ------------------------------------

\renewcommand\topfraction{.85}
\renewcommand\bottomfraction{.7}
\renewcommand\textfraction{.15}
\renewcommand\floatpagefraction{.66}
\renewcommand\dbltopfraction{.66}
\renewcommand\dblfloatpagefraction{.66}

\def\fps@figure{htb}
\def\fps@table{htb}

\setlength{\floatsep}{6bp}
\setlength{\textfloatsep}{6bp}
\setlength{\intextsep}{6bp}

% 表格默认字号
\AtBeginEnvironment{tabular}{\fontsize{8bp}{9.6bp}\selectfont}

\captionsetup{
  format         = hang,
  font           = small,
  labelsep       = quad,
  skip           = 4bp,
  figureposition = bottom,
  tableposition  = top,
}

\DeclareCaptionFont{heiti}{\heiti}
\captionsetup[table]{font+=heiti}

%--------------------------------- 参考文献 ------------------------------------

\newcommand\bibstyle@npr{\bibpunct{[}{]}{,}{s}{,}{\textsuperscript{,}}}
\citestyle{npr}

\renewcommand\NAT@citesuper[3]{\ifNAT@swa
\if*#2*\else#2\NAT@spacechar\fi
\unskip\kern\p@\textsuperscript{\NAT@@open#1\NAT@@close\if*#3*\else#3\fi}%
   \else #1\fi\endgroup}
\renewcommand\NAT@citenum%
    [3]{\ifNAT@swa\NAT@@open\if*#2*\else#2\NAT@spacechar\fi
        #1\NAT@@close\if*#3*\else\textsuperscript{#3}\fi\else#1\fi\endgroup}
\patchcmd{\NAT@citex}{%
  \if*#2*\else\NAT@cmt#2\fi
  \if\relax\NAT@date\relax\else\NAT@@close\fi
}{%
  \if\relax\NAT@date\relax\else\NAT@@close\fi
  \if*#2*\else\textsuperscript{#2}\fi
}{}{\fail}
\renewcommand\NAT@cite%
    [3]{\ifNAT@swa\NAT@@open\if*#2*\else#2\NAT@spacechar\fi
        #1\NAT@@close\if*#3*\else\textsuperscript{#3}\fi\else#1\fi\endgroup}
\patchcmd{\NAT@citexnum}{%
  \ifx\NAT@last@yr\relax
    \def@NAT@last@yr{\@citea}%
  \else
    \def@NAT@last@yr{--\NAT@penalty}%
  \fi
}{%
  \def@NAT@last@yr{-\NAT@penalty}%
}{}{\fail}

\renewcommand\bibfont{\fontsize{8bp}{9.6bp}\selectfont}
\setlength{\bibsep}{\z@}
\renewcommand\@biblabel[1]{[#1]}

\renewcommand\newblock{\space}


% 宏包的补充配置

% hyperref
\AtEndOfPackageFile*{hyperref}{
  \hypersetup{
    unicode            = true,
    psdextra           = true,
    colorlinks         = true,
    allcolors          = black,
    urlcolor           = blue,
    linktoc            = all,
    bookmarksnumbered  = true,
    bookmarksopen      = true,
    bookmarksopenlevel = 2,
  }
  \DeclareRobustCommand\@doi[1]{\href{https://doi.org/#1}{\nolinkurl{#1}}}
  \DeclareRobustCommand\@email[1]{\href{mailto:#1}{\nolinkurl{#1}}}
  \pdfstringdefDisableCommands{
    \let\\\@empty
    \let\hspace\@gobble
  }
  \@ifpackagelater{hyperref}{2019/04/27}{}{%
    \g@addto@macro\psdmapshortnames{\let\mu\textmu}%
  }
}

% siunitx
\AtEndOfPackageFile*{siunitx}{
  \sisetup{
    group-minimum-digits = 4,
    separate-uncertainty = true,
    inter-unit-product   = \ensuremath{{}\cdot{}},
    list-units           = single,
    range-units          = single,
  }
  \newcommand\class@set@siunitx@language{%
    \ifclass@language@chinese
      \sisetup{
        list-final-separator = { 和 },
        list-pair-separator  = { 和 },
        range-phrase         = {～},
      }%
    \else
      \ifclass@language@english
        \sisetup{
          list-final-separator = { and },
          list-pair-separator  = { and },
          range-phrase         = { to },
        }%
      \fi
    \fi
  }
  \class@set@siunitx@language
  \class@option@hook{language}{\class@set@siunitx@language}
}

%%
%% End of file `npr.cls'.
